==> openGion6.1.2.0_dev.zip: uap/webapps/gf/db/mysql/sql/install/02_INDEX/AllDropC.sql <==

ALTER TABLE BONUS DROP INDEX BONUS_UQ;
ALTER TABLE DEPT DROP INDEX DEPT_UQ;
ALTER TABLE DEPT DROP INDEX DEPT_SA;
ALTER TABLE EMP DROP INDEX EMP_UQ;
ALTER TABLE EMP DROP INDEX EMP_SB;
ALTER TABLE GF01 DROP INDEX GF01_UQ;
ALTER TABLE GF01 DROP INDEX GF01_LUQ;
ALTER TABLE GF01 DROP INDEX GF01_SA;
ALTER TABLE GF02 DROP INDEX GF02_UQ;
ALTER TABLE GF02 DROP INDEX GF02_LUQ;
ALTER TABLE GF02 DROP INDEX GF02_SA;
ALTER TABLE GF03 DROP INDEX GF03_UQ;
ALTER TABLE GF03 DROP INDEX GF03_LUQ;
ALTER TABLE GF05 DROP INDEX GF05_UQ;
ALTER TABLE GF05 DROP INDEX GF05_LUQ;
ALTER TABLE GF05 DROP INDEX GF05_SA;
ALTER TABLE GF06 DROP INDEX GF06_UQ;
ALTER TABLE GF06 DROP INDEX GF06_LUQ;
ALTER TABLE GF07 DROP INDEX GF07_UQ;
ALTER TABLE GF07 DROP INDEX GF07_LUQ;
ALTER TABLE GF07 DROP INDEX GF07_SA;
ALTER TABLE GF09 DROP INDEX GF09_UQ;
ALTER TABLE GF09 DROP INDEX GF09_LUQ;
ALTER TABLE GF13 DROP INDEX GF13_UQ;
ALTER TABLE GF13 DROP INDEX GF13_LUQ;
ALTER TABLE GF19 DROP INDEX GF19_UQ;
ALTER TABLE GF19 DROP INDEX GF19_LUQ;
ALTER TABLE GF21 DROP INDEX GF21_UQ;
ALTER TABLE GF21 DROP INDEX GF21_LUQ;
ALTER TABLE GF21 DROP INDEX GF21_SA;
ALTER TABLE GF22 DROP INDEX GF22_UQ;
ALTER TABLE GF22 DROP INDEX GF22_LUQ;
ALTER TABLE GF22 DROP INDEX GF22_SA;
ALTER TABLE GF23 DROP INDEX GF23_UQ;
ALTER TABLE GF23 DROP INDEX GF23_LUQ;
ALTER TABLE GF24 DROP INDEX GF24_UQ;
ALTER TABLE GF24 DROP INDEX GF24_LUQ;
ALTER TABLE GF25 DROP INDEX GF25_UQ;
ALTER TABLE GF25 DROP INDEX GF25_LUQ;
ALTER TABLE GF25 DROP INDEX GF25_SA;
ALTER TABLE GF27 DROP INDEX GF27_UQ;
ALTER TABLE GF27 DROP INDEX GF27_LUQ;
ALTER TABLE GF27 DROP INDEX GF27_SA;
ALTER TABLE GF27 DROP INDEX GF27_SB;
ALTER TABLE GF27 DROP INDEX GF27_SC;
ALTER TABLE GF28 DROP INDEX GF28_UQ;
ALTER TABLE GF28 DROP INDEX GF28_LUQ;
ALTER TABLE GF28 DROP INDEX GF28_SA;
ALTER TABLE GF41 DROP INDEX GF41_UQ;
ALTER TABLE GF41 DROP INDEX GF41_LUQ;
ALTER TABLE GF42 DROP INDEX GF42_LUQ;
ALTER TABLE GF42 DROP INDEX GF42_SA;
ALTER TABLE GF42 DROP INDEX GF42_SB;
ALTER TABLE GF42 DROP INDEX GF42_SC;
ALTER TABLE GF42 DROP INDEX GF42_SD;
ALTER TABLE GF42 DROP INDEX GF42_SE;
ALTER TABLE GF42 DROP INDEX GF42_SF;
ALTER TABLE GF43 DROP INDEX GF43_UQ;
ALTER TABLE GF43 DROP INDEX GF43_SA;
ALTER TABLE GF44 DROP INDEX GF44_UQ;
ALTER TABLE GF44 DROP INDEX GF44_LUQ;
ALTER TABLE GF45 DROP INDEX GF45_UQ;
ALTER TABLE GF45 DROP INDEX GF45_LUQ;
ALTER TABLE GF46 DROP INDEX GF46_UQ;
ALTER TABLE GF46 DROP INDEX GF46_LUQ;
ALTER TABLE GF60 DROP INDEX GF60_UQ;
ALTER TABLE GF60 DROP INDEX GF60_LUQ;
ALTER TABLE GF60 DROP INDEX GF60_SA;
ALTER TABLE GF60 DROP INDEX GF60_SB;
ALTER TABLE GF61 DROP INDEX GF61_UQ;
ALTER TABLE GF61 DROP INDEX GF61_LUQ;
ALTER TABLE GF61 DROP INDEX GF61_SA;
ALTER TABLE GF62 DROP INDEX GF62_UQ;
ALTER TABLE GF62 DROP INDEX GF62_LUQ;
ALTER TABLE GF62 DROP INDEX GF62_SA;
ALTER TABLE GF62 DROP INDEX GF62_SB;
ALTER TABLE GF63 DROP INDEX GF63_UQ;
ALTER TABLE GF63 DROP INDEX GF63_LUQ;
ALTER TABLE GF63 DROP INDEX GF63_SA;
ALTER TABLE GF64 DROP INDEX GF64_UQ;
ALTER TABLE GF64 DROP INDEX GF64_LUQ;
ALTER TABLE GF64 DROP INDEX GF64_SA;
ALTER TABLE GF65 DROP INDEX GF65_UQ;
ALTER TABLE GF65 DROP INDEX GF65_LUQ;
ALTER TABLE GF65 DROP INDEX GF65_SA;
ALTER TABLE GF66 DROP INDEX GF66_UQ;
ALTER TABLE GF66 DROP INDEX GF66_LUQ;
ALTER TABLE GF66 DROP INDEX GF66_SA;
ALTER TABLE GF67 DROP INDEX GF67_UQ;
ALTER TABLE GF67 DROP INDEX GF67_LUQ;
ALTER TABLE GF68 DROP INDEX GF68_UQ;
ALTER TABLE GF68 DROP INDEX GF68_LUQ;
ALTER TABLE GF69 DROP INDEX GF69_UQ;
ALTER TABLE GF69 DROP INDEX GF69_LUQ;
ALTER TABLE GF69 DROP INDEX GF69_SA;
ALTER TABLE GF69 DROP INDEX GF69_SC;
ALTER TABLE GF70 DROP INDEX GF70_UQ;
ALTER TABLE GF70 DROP INDEX GF70_SA;
ALTER TABLE GF70 DROP INDEX GF70_SB;
ALTER TABLE GF70 DROP INDEX GF70_SC;
ALTER TABLE GF71 DROP INDEX GF71_UQ;
ALTER TABLE GF71 DROP INDEX GF71_SA;
ALTER TABLE GF71 DROP INDEX GF71_SB;
ALTER TABLE GF71 DROP INDEX GF71_SC;
ALTER TABLE GF72 DROP INDEX GF72_UQ;
ALTER TABLE GF72 DROP INDEX GF72_SA;
ALTER TABLE GF72 DROP INDEX GF72_SB;
ALTER TABLE GF72 DROP INDEX GF72_SC;
ALTER TABLE GF73 DROP INDEX GF73_UQ;
ALTER TABLE GF73 DROP INDEX GF73_SA;
ALTER TABLE GF73 DROP INDEX GF73_SB;
ALTER TABLE GF73 DROP INDEX GF73_SC;
ALTER TABLE GF74 DROP INDEX GF74_UQ;
ALTER TABLE GF74 DROP INDEX GF74_SA;
ALTER TABLE GF74 DROP INDEX GF74_SB;
ALTER TABLE GF75 DROP INDEX GF75_UQ;
ALTER TABLE GF75 DROP INDEX GF75_SA;
ALTER TABLE GF75 DROP INDEX GF75_SB;
ALTER TABLE GF75 DROP INDEX GF75_SC;
ALTER TABLE GF76 DROP INDEX GF76_UQ;
ALTER TABLE GF76 DROP INDEX GF76_SA;
ALTER TABLE GF76 DROP INDEX GF76_SB;
ALTER TABLE GF77 DROP INDEX GF77_UQ;
ALTER TABLE GF77 DROP INDEX GF77_SA;
ALTER TABLE GF77 DROP INDEX GF77_SB;
ALTER TABLE GF77 DROP INDEX GF77_SC;
ALTER TABLE GF78 DROP INDEX GF78_UQ;
ALTER TABLE GF78 DROP INDEX GF78_LUQ;
ALTER TABLE GF78 DROP INDEX GF78_SA;
ALTER TABLE GF78 DROP INDEX GF78_SB;
ALTER TABLE GF80 DROP INDEX GF80_UQ;
ALTER TABLE GF80 DROP INDEX GF80_LUQ;
ALTER TABLE GF80 DROP INDEX GF80_SA;
ALTER TABLE GF81 DROP INDEX GF81_UQ;
ALTER TABLE GF81 DROP INDEX GF81_LUQ;
ALTER TABLE GF81 DROP INDEX GF81_SA;
ALTER TABLE GF82 DROP INDEX GF82_UQ;
ALTER TABLE GF82 DROP INDEX GF82_LUQ;
ALTER TABLE GF83 DROP INDEX GF83_UQ;
ALTER TABLE GF83 DROP INDEX GF83_SA;
ALTER TABLE GF84 DROP INDEX GF84_UQ;
ALTER TABLE GF84 DROP INDEX GF84_LUQ;
ALTER TABLE GF84 DROP INDEX GF84_SA;
ALTER TABLE GF84 DROP INDEX GF84_SB;
ALTER TABLE GF85 DROP INDEX GF85_UQ;
ALTER TABLE GF85 DROP INDEX GF85_LUQ;
ALTER TABLE GF85 DROP INDEX GF85_SA;
ALTER TABLE GF85 DROP INDEX GF85_SB;
ALTER TABLE GF90 DROP INDEX GF90_UQ;
ALTER TABLE GF90 DROP INDEX GF90_LUQ;
ALTER TABLE GF90 DROP INDEX GF90_SA;
ALTER TABLE GF90 DROP INDEX GF90_SB;
ALTER TABLE GF90 DROP INDEX GF90_SC;
ALTER TABLE GF90 DROP INDEX GF90_SD;
ALTER TABLE GF90 DROP INDEX GF90_SE;
ALTER TABLE GF91 DROP INDEX GF91_UQ;
ALTER TABLE GF91 DROP INDEX GF91_LUQ;
ALTER TABLE GF91 DROP INDEX GF91_SA;
ALTER TABLE GF92 DROP INDEX GF92_UQ;
ALTER TABLE GF92 DROP INDEX GF92_LUQ;
ALTER TABLE GF92 DROP INDEX GF92_SA;
ALTER TABLE GF92 DROP INDEX GF92_SB;
ALTER TABLE GF92 DROP INDEX GF92_SC;
ALTER TABLE GF93 DROP INDEX GF93_UQ;
ALTER TABLE GF93 DROP INDEX GF93_SA;
ALTER TABLE GF94 DROP INDEX GF94_UQ;
ALTER TABLE GF94 DROP INDEX GF94_SA;
ALTER TABLE GF94 DROP INDEX GF94_SB;
ALTER TABLE GF95 DROP INDEX GF95_UQ;
ALTER TABLE GF95 DROP INDEX GF95_LUQ;
ALTER TABLE GF95 DROP INDEX GF95_SA;
ALTER TABLE GF96 DROP INDEX GF96_UQ;
ALTER TABLE GF96 DROP INDEX GF96_LUQ;
ALTER TABLE GF96 DROP INDEX GF96_SA;
ALTER TABLE GF96 DROP INDEX GF96_SB;
ALTER TABLE GF96 DROP INDEX GF96_SC;
ALTER TABLE GFW41 DROP INDEX GFW41_UQ;
ALTER TABLE GFW41 DROP INDEX GFW41_LUQ;
ALTER TABLE GFX01 DROP INDEX GFX01_LUQ;
ALTER TABLE GFX02 DROP INDEX GFX02_LUQ;

==> openGion6.3.0.0_dev.zip: uap/webapps/gf/db/mysql/sql/install/02_INDEX/AllDropC.sql <==

ALTER TABLE BONUS DROP INDEX BONUS_UQ;
ALTER TABLE DEPT DROP INDEX DEPT_UQ;
ALTER TABLE DEPT DROP INDEX DEPT_SA;
ALTER TABLE EMP DROP INDEX EMP_UQ;
ALTER TABLE EMP DROP INDEX EMP_SB;
ALTER TABLE GF01 DROP INDEX GF01_UQ;
ALTER TABLE GF01 DROP INDEX GF01_LUQ;
ALTER TABLE GF01 DROP INDEX GF01_SA;
ALTER TABLE GF02 DROP INDEX GF02_UQ;
ALTER TABLE GF02 DROP INDEX GF02_LUQ;
ALTER TABLE GF02 DROP INDEX GF02_SA;
ALTER TABLE GF03 DROP INDEX GF03_UQ;
ALTER TABLE GF03 DROP INDEX GF03_LUQ;
ALTER TABLE GF05 DROP INDEX GF05_UQ;
ALTER TABLE GF05 DROP INDEX GF05_LUQ;
ALTER TABLE GF05 DROP INDEX GF05_SA;
ALTER TABLE GF06 DROP INDEX GF06_UQ;
ALTER TABLE GF06 DROP INDEX GF06_LUQ;
ALTER TABLE GF07 DROP INDEX GF07_UQ;
ALTER TABLE GF07 DROP INDEX GF07_LUQ;
ALTER TABLE GF07 DROP INDEX GF07_SA;
ALTER TABLE GF09 DROP INDEX GF09_UQ;
ALTER TABLE GF09 DROP INDEX GF09_LUQ;
ALTER TABLE GF13 DROP INDEX GF13_UQ;
ALTER TABLE GF13 DROP INDEX GF13_LUQ;
ALTER TABLE GF19 DROP INDEX GF19_UQ;
ALTER TABLE GF19 DROP INDEX GF19_LUQ;
ALTER TABLE GF21 DROP INDEX GF21_UQ;
ALTER TABLE GF21 DROP INDEX GF21_LUQ;
ALTER TABLE GF21 DROP INDEX GF21_SA;
ALTER TABLE GF22 DROP INDEX GF22_UQ;
ALTER TABLE GF22 DROP INDEX GF22_LUQ;
ALTER TABLE GF22 DROP INDEX GF22_SA;
ALTER TABLE GF23 DROP INDEX GF23_UQ;
ALTER TABLE GF23 DROP INDEX GF23_LUQ;
ALTER TABLE GF24 DROP INDEX GF24_UQ;
ALTER TABLE GF24 DROP INDEX GF24_LUQ;
ALTER TABLE GF25 DROP INDEX GF25_UQ;
ALTER TABLE GF25 DROP INDEX GF25_LUQ;
ALTER TABLE GF25 DROP INDEX GF25_SA;
ALTER TABLE GF27 DROP INDEX GF27_UQ;
ALTER TABLE GF27 DROP INDEX GF27_LUQ;
ALTER TABLE GF27 DROP INDEX GF27_SA;
ALTER TABLE GF27 DROP INDEX GF27_SB;
ALTER TABLE GF27 DROP INDEX GF27_SC;
ALTER TABLE GF28 DROP INDEX GF28_UQ;
ALTER TABLE GF28 DROP INDEX GF28_SA;
ALTER TABLE GF28 DROP INDEX GF28_SB;
ALTER TABLE GF28 DROP INDEX GF28_SC;
ALTER TABLE GF41 DROP INDEX GF41_UQ;
ALTER TABLE GF41 DROP INDEX GF41_LUQ;
ALTER TABLE GF42 DROP INDEX GF42_LUQ;
ALTER TABLE GF42 DROP INDEX GF42_SA;
ALTER TABLE GF42 DROP INDEX GF42_SB;
ALTER TABLE GF42 DROP INDEX GF42_SC;
ALTER TABLE GF42 DROP INDEX GF42_SD;
ALTER TABLE GF42 DROP INDEX GF42_SE;
ALTER TABLE GF42 DROP INDEX GF42_SF;
ALTER TABLE GF43 DROP INDEX GF43_UQ;
ALTER TABLE GF43 DROP INDEX GF43_SA;
ALTER TABLE GF44 DROP INDEX GF44_UQ;
ALTER TABLE GF44 DROP INDEX GF44_LUQ;
ALTER TABLE GF45 DROP INDEX GF45_UQ;
ALTER TABLE GF45 DROP INDEX GF45_LUQ;
ALTER TABLE GF46 DROP INDEX GF46_UQ;
ALTER TABLE GF46 DROP INDEX GF46_LUQ;
ALTER TABLE GF60 DROP INDEX GF60_UQ;
ALTER TABLE GF60 DROP INDEX GF60_LUQ;
ALTER TABLE GF60 DROP INDEX GF60_SA;
ALTER TABLE GF60 DROP INDEX GF60_SB;
ALTER TABLE GF61 DROP INDEX GF61_UQ;
ALTER TABLE GF61 DROP INDEX GF61_LUQ;
ALTER TABLE GF61 DROP INDEX GF61_SA;
ALTER TABLE GF62 DROP INDEX GF62_UQ;
ALTER TABLE GF62 DROP INDEX GF62_LUQ;
ALTER TABLE GF62 DROP INDEX GF62_SA;
ALTER TABLE GF62 DROP INDEX GF62_SB;
ALTER TABLE GF63 DROP INDEX GF63_UQ;
ALTER TABLE GF63 DROP INDEX GF63_LUQ;
ALTER TABLE GF63 DROP INDEX GF63_SA;
ALTER TABLE GF64 DROP INDEX GF64_UQ;
ALTER TABLE GF64 DROP INDEX GF64_LUQ;
ALTER TABLE GF64 DROP INDEX GF64_SA;
ALTER TABLE GF65 DROP INDEX GF65_UQ;
ALTER TABLE GF65 DROP INDEX GF65_LUQ;
ALTER TABLE GF65 DROP INDEX GF65_SA;
ALTER TABLE GF66 DROP INDEX GF66_UQ;
ALTER TABLE GF66 DROP INDEX GF66_LUQ;
ALTER TABLE GF66 DROP INDEX GF66_SA;
ALTER TABLE GF67 DROP INDEX GF67_UQ;
ALTER TABLE GF67 DROP INDEX GF67_LUQ;
ALTER TABLE GF68 DROP INDEX GF68_UQ;
ALTER TABLE GF68 DROP INDEX GF68_LUQ;
ALTER TABLE GF69 DROP INDEX GF69_UQ;
ALTER TABLE GF69 DROP INDEX GF69_LUQ;
ALTER TABLE GF69 DROP INDEX GF69_SA;
ALTER TABLE GF69 DROP INDEX GF69_SC;
ALTER TABLE GF70 DROP INDEX GF70_UQ;
ALTER TABLE GF70 DROP INDEX GF70_SA;
ALTER TABLE GF70 DROP INDEX GF70_SB;
ALTER TABLE GF70 DROP INDEX GF70_SC;
ALTER TABLE GF71 DROP INDEX GF71_UQ;
ALTER TABLE GF71 DROP INDEX GF71_SA;
ALTER TABLE GF71 DROP INDEX GF71_SB;
ALTER TABLE GF71 DROP INDEX GF71_SC;
ALTER TABLE GF72 DROP INDEX GF72_UQ;
ALTER TABLE GF72 DROP INDEX GF72_SA;
ALTER TABLE GF72 DROP INDEX GF72_SB;
ALTER TABLE GF72 DROP INDEX GF72_SC;
ALTER TABLE GF73 DROP INDEX GF73_UQ;
ALTER TABLE GF73 DROP INDEX GF73_SA;
ALTER TABLE GF73 DROP INDEX GF73_SB;
ALTER TABLE GF73 DROP INDEX GF73_SC;
ALTER TABLE GF74 DROP INDEX GF74_UQ;
ALTER TABLE GF74 DROP INDEX GF74_SA;
ALTER TABLE GF74 DROP INDEX GF74_SB;
ALTER TABLE GF75 DROP INDEX GF75_UQ;
ALTER TABLE GF75 DROP INDEX GF75_SA;
ALTER TABLE GF75 DROP INDEX GF75_SB;
ALTER TABLE GF75 DROP INDEX GF75_SC;
ALTER TABLE GF76 DROP INDEX GF76_UQ;
ALTER TABLE GF76 DROP INDEX GF76_SA;
ALTER TABLE GF76 DROP INDEX GF76_SB;
ALTER TABLE GF77 DROP INDEX GF77_UQ;
ALTER TABLE GF77 DROP INDEX GF77_SA;
ALTER TABLE GF77 DROP INDEX GF77_SB;
ALTER TABLE GF77 DROP INDEX GF77_SC;
ALTER TABLE GF78 DROP INDEX GF78_UQ;
ALTER TABLE GF78 DROP INDEX GF78_LUQ;
ALTER TABLE GF78 DROP INDEX GF78_SA;
ALTER TABLE GF78 DROP INDEX GF78_SB;
ALTER TABLE GF80 DROP INDEX GF80_UQ;
ALTER TABLE GF80 DROP INDEX GF80_LUQ;
ALTER TABLE GF80 DROP INDEX GF80_SA;
ALTER TABLE GF81 DROP INDEX GF81_UQ;
ALTER TABLE GF81 DROP INDEX GF81_LUQ;
ALTER TABLE GF81 DROP INDEX GF81_SA;
ALTER TABLE GF82 DROP INDEX GF82_UQ;
ALTER TABLE GF82 DROP INDEX GF82_LUQ;
ALTER TABLE GF83 DROP INDEX GF83_UQ;
ALTER TABLE GF83 DROP INDEX GF83_SA;
ALTER TABLE GF84 DROP INDEX GF84_UQ;
ALTER TABLE GF84 DROP INDEX GF84_LUQ;
ALTER TABLE GF84 DROP INDEX GF84_SA;
ALTER TABLE GF84 DROP INDEX GF84_SB;
ALTER TABLE GF85 DROP INDEX GF85_UQ;
ALTER TABLE GF85 DROP INDEX GF85_LUQ;
ALTER TABLE GF85 DROP INDEX GF85_SA;
ALTER TABLE GF85 DROP INDEX GF85_SB;
ALTER TABLE GF90 DROP INDEX GF90_UQ;
ALTER TABLE GF90 DROP INDEX GF90_LUQ;
ALTER TABLE GF90 DROP INDEX GF90_SA;
ALTER TABLE GF90 DROP INDEX GF90_SB;
ALTER TABLE GF90 DROP INDEX GF90_SC;
ALTER TABLE GF90 DROP INDEX GF90_SD;
ALTER TABLE GF90 DROP INDEX GF90_SE;
ALTER TABLE GF91 DROP INDEX GF91_UQ;
ALTER TABLE GF91 DROP INDEX GF91_LUQ;
ALTER TABLE GF91 DROP INDEX GF91_SA;
ALTER TABLE GF92 DROP INDEX GF92_UQ;
ALTER TABLE GF92 DROP INDEX GF92_LUQ;
ALTER TABLE GF92 DROP INDEX GF92_SA;
ALTER TABLE GF92 DROP INDEX GF92_SB;
ALTER TABLE GF92 DROP INDEX GF92_SC;
ALTER TABLE GF93 DROP INDEX GF93_UQ;
ALTER TABLE GF93 DROP INDEX GF93_SA;
ALTER TABLE GF94 DROP INDEX GF94_UQ;
ALTER TABLE GF94 DROP INDEX GF94_SA;
ALTER TABLE GF94 DROP INDEX GF94_SB;
ALTER TABLE GF95 DROP INDEX GF95_UQ;
ALTER TABLE GF95 DROP INDEX GF95_LUQ;
ALTER TABLE GF95 DROP INDEX GF95_SA;
ALTER TABLE GF96 DROP INDEX GF96_UQ;
ALTER TABLE GF96 DROP INDEX GF96_LUQ;
ALTER TABLE GF96 DROP INDEX GF96_SA;
ALTER TABLE GF96 DROP INDEX GF96_SB;
ALTER TABLE GF96 DROP INDEX GF96_SC;
ALTER TABLE GFW41 DROP INDEX GFW41_UQ;
ALTER TABLE GFW41 DROP INDEX GFW41_LUQ;
ALTER TABLE GFX01 DROP INDEX GFX01_LUQ;
ALTER TABLE GFX02 DROP INDEX GFX02_LUQ;
